@@ -682,29 +682,31 @@ def daterange(start_date, end_date):
 
 # noinspection PyPep8Naming
 class ECMWF_variable(object):
-    def __init__(self, variable, path_db, var_date, dtype=np.float32, logger=None):
+    def __init__(self, variable, path_db, delta_day, var_date, dtype=np.float32, logger=None):
         """
+        Initialize a selected ECMWF variable. Raise FileNotFoundError if file is not found in database.
 
-        :param variable: name string as valid for ECMWF_download
-        :param path_db: root of database for ECMWF data
-        :param var_date: date object
-        :return:
-        :raise FileNotFoundError if file is not found in database
+        :param variable:  name string as valid for ECMWF_download
+        :param path_db:   root of database for ECMWF data
+        :param delta_day: deviation of database date from sensing date
+        :param var_date:  date object
         """
         self.logger = logging.getLogger() if logger is None else logger
         self.fn = ECMWF_download.db_path(variable, var_date, path_db)
 
-        if not isfile(self.fn):  # raise if file doesnt exists
+        if not isfile(self.fn):  # raise if file doesn't exist
             raise FileNotFoundError(self.fn)
+        if delta_day != 0:
+            self.logger.warning("ECMWF data of a different date than the acquisition day are used.")
 
         h5f = h5py.File(name=self.fn, mode="r")
         if 'steps' not in h5f.keys():
             self.steps = np.array([0], dtype=dtype)
         else:
-            self.steps = np.array(h5f["steps"].value[:], dtype=dtype)
-        self.lat = np.array(h5f["lat"].value[:], dtype=dtype)
-        self.lon = np.array(h5f["lon"].value[:], dtype=dtype)
-        self.variable = np.array(h5f[variable].value[:, :, :], dtype=dtype)
+            self.steps = np.array(h5f["steps"][()][:], dtype=dtype)
+        self.lat = np.array(h5f["lat"][()][:], dtype=dtype)
+        self.lon = np.array(h5f["lon"][()][:], dtype=dtype)
+        self.variable = np.array(h5f[variable][()][:, :, :], dtype=dtype)
         self.var = RegularGridInterpolator(points=(self.steps, self.lat[::-1], self.lon),
                                            values=self.variable[:, ::-1, :], method="linear")
         h5f.close()
